SystemOrganization addCategory: #'Glamour-Presentations'!

Trait named: #GLMTBlockTags
	uses: {}
	category: 'Glamour-Presentations'!

!GLMTBlockTags commentStamp: 'AndreiChis 4/20/2014 23:10' prior: 0!
I provide an api for computing tags.!

!GLMTBlockTags methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 22:51'!
computeTagsFilterFor: aGlamourValue 

	^ self computeTagsFor: aGlamourValue from: self tagsFilterBlock! !

!GLMTBlockTags methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 22:51'!
computeTagsFor: aGlamourValue 

	^ self computeTagsFor: aGlamourValue from: self tagsBlock! !

!GLMTBlockTags methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 22:51'!
computeTagsFor: aGlamourValue from: aBlock
	| value |
	
	aBlock ifNil: [ ^ OrderedCollection new ].
	value := aBlock glamourValue: aGlamourValue.
	^ value isString
		ifTrue: [ OrderedCollection with: value ]
		ifFalse: [ value asOrderedCollection ]! !

!GLMTBlockTags methodsFor: 'testing' stamp: 'AndreiChis 4/20/2014 22:48'!
hasTags
	^ self tagsBlock notNil! !

!GLMTBlockTags methodsFor: 'testing' stamp: 'AndreiChis 4/20/2014 22:48'!
hasTagsFilter
	^ self tagsFilterBlock notNil! !

!GLMTBlockTags methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 22:53'!
tags: aBlock

	self tagsBlock: aBlock.
	self hasTagsFilter ifFalse:[ self tagsFilter: aBlock ]! !

!GLMTBlockTags methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 22:50'!
tagsBlock
	self explicitRequirement! !

!GLMTBlockTags methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 22:50'!
tagsBlock: anObject
	self explicitRequirement! !

!GLMTBlockTags methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 22:50'!
tagsFilter: anObject
	self explicitRequirement! !

!GLMTBlockTags methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 22:50'!
tagsFilterBlock
	self explicitRequirement! !

GLMPresentation subclass: #GLMDynamicPresentation
	instanceVariableNames: 'presentationTransformation cachedPresentation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDynamicPresentation commentStamp: 'tg 9/20/2009 14:25' prior: 0!
A GLMDynamicPresentation is a presentation that takes the actual presentation from the display value. Like this, we can have the block of display return a presentation depending on the input.

A usage for this behavior is the Glamorous Editor, which takes the text as input and based on this it displays the browser.!

!GLMDynamicPresentation methodsFor: 'rendering' stamp: 'TudorGirba 5/25/2013 12:11'!
cachedPresentation
	"currentPresentation applies the transformation dynamically.
	This means that calling it twice, will retrieve two different objects.
	To solve the problem, cachedPresentation stores the last currentPresentation, and 
	it can be used for further inspection"
	^ cachedPresentation! !

!GLMDynamicPresentation methodsFor: 'rendering' stamp: 'AndreiChis 6/24/2013 13:24'!
currentPresentation 
	| composite |
	composite := GLMCompositePresentation new.
	self presentationTransformation glamourValue: (
			composite asGlamorousMultiValue, 
			self displayValue asGlamorousMultiValue).
	composite pane: self pane.
	composite initializePresentation.
	cachedPresentation := composite.
	^ composite
"	^ self displayValue pane: self pane"! !

!GLMDynamicPresentation methodsFor: 'initialize-release' stamp: ''!
initialize 
	super initialize.
	presentationTransformation := [ :aComposite :each | aComposite custom: each ]! !

!GLMDynamicPresentation methodsFor: 'scripting' stamp: ''!
presentation: aBlock
	self presentationTransformation: aBlock! !

!GLMDynamicPresentation methodsFor: 'accessing' stamp: ''!
presentationTransformation
	^ presentationTransformation! !

!GLMDynamicPresentation methodsFor: 'accessing' stamp: ''!
presentationTransformation: anObject
	presentationTransformation := anObject! !

!GLMDynamicPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderDynamicPresentation: self! !

!GLMDynamicPresentation methodsFor: 'scripting' stamp: ''!
with: aBlock
	self presentationTransformation: aBlock! !

!GLMDynamicPresentation methodsFor: 'enumerating' stamp: 'TudorGirba 5/25/2013 12:12'!
withAllPanesAndPresentationsDo: aBlock
	super withAllPanesAndPresentationsDo: aBlock.
	self cachedPresentation ifNotNil: [ :presentation | presentation withAllPanesAndPresentationsDo: aBlock ]! !

GLMPresentation subclass: #GLMFlexiblePresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMFlexiblePresentation commentStamp: '<historical>' prior: 0!
A presentation that flexibly changes it behavior depending on the current entity.

If the entity is a collection, this class renders as a ListPresentation, otherwise as a TextPresentation.!

!GLMFlexiblePresentation methodsFor: 'accessing' stamp: ''!
currentPresentation 
	 
	^ (self displayValue isCollection and: [self displayValue isString not])
		ifTrue: [GLMListPresentation new showOnly: 50; pane: self pane]
		ifFalse: [GLMTextPresentation new pane: self pane]! !

!GLMFlexiblePresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements. 
	^self currentPresentation renderGlamorouslyOn: aRenderer! !

GLMPresentation subclass: #GLMMorphPresentation
	instanceVariableNames: 'morphBuilder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMMorphPresentation commentStamp: 'TudorGirba 2/4/2011 21:13' prior: 0!
This presentation offers a means to embed a Morph. It makes sense only for the Morph Renderer.!

!GLMMorphPresentation methodsFor: 'initialization' stamp: 'TudorGirba 1/9/2014 15:12'!
initialize
	super initialize.
	morphBuilder := [ :thisPresentation :theDisplayValue | theDisplayValue asMorph ]! !

!GLMMorphPresentation methodsFor: 'rendering' stamp: 'TudorGirba 1/9/2014 15:12'!
morph
	^ morphBuilder glamourValue: 
			(self asGlamorousMultiValue, 
			self displayValue asGlamorousMultiValue)! !

!GLMMorphPresentation methodsFor: 'rendering' stamp: 'TudorGirba 1/9/2014 15:01'!
morph: aBlock
	morphBuilder := aBlock! !

!GLMMorphPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderMorphPresentation: self! !

GLMPresentation subclass: #GLMSpecPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMSpecPresentation methodsFor: 'as yet unclassified' stamp: 'TudorGirba 4/3/2013 16:48'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderSpecPresentation: self! !

Object subclass: #GLMTableColumn
	uses: GLMTBlockTags
	instanceVariableNames: 'title computation width tagsBlock tagsFilterBlock sortBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTableColumn commentStamp: 'TudorGirba 2/4/2011 21:14' prior: 0!
This is a helper class for the TablePresentation.

Instance Variables:
	title	<ProtoObject | PseudoContext>
	computation	<ProtoObject | PseudoContext>!

GLMTableColumn class
	uses: GLMTBlockTags classTrait
	instanceVariableNames: ''!

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
computation
	^ computation! !

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
computation: anObject
	computation := anObject! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/21/2014 12:34'!
sortBlock
	^ sortBlock! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/21/2014 12:34'!
sortBlock: aBlock
	sortBlock := aBlock! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/17/2014 23:56'!
tagsBlock
	^ tagsBlock! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 22:55'!
tagsBlock: aBlock
	tagsBlock := aBlock! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 22:54'!
tagsFilter: aBlock
	tagsFilterBlock := aBlock ! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'AndreiChis 4/17/2014 23:57'!
tagsFilterBlock
	^ tagsFilterBlock! !

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
title
	^ title! !

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
title: anObject
	title := anObject! !

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
width
	^ width ifNil: [200]! !

!GLMTableColumn methodsFor: 'accessing' stamp: ''!
width: anObject
	width := anObject! !

GLMFormatedPresentation subclass: #GLMActionListPresentation
	instanceVariableNames: 'isHorizontal'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMActionListPresentation methodsFor: 'scripting' stamp: 'AndreiChis 8/6/2013 18:48'!
beVertical
	self isHorizontal: false! !

!GLMActionListPresentation methodsFor: 'testing' stamp: 'EstebanLorenzano 4/20/2012 16:19'!
hasActions
	^false! !

!GLMActionListPresentation methodsFor: 'accessing' stamp: 'AndreiChis 8/6/2013 18:34'!
isHorizontal
	^ isHorizontal ifNil: [isHorizontal := true]! !

!GLMActionListPresentation methodsFor: 'accessing' stamp: ''!
isHorizontal: anObject
	isHorizontal := anObject! !

!GLMActionListPresentation methodsFor: 'accessing' stamp: ''!
isVertical
	^ self isHorizontal not! !

!GLMActionListPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer
	self registerAnnouncements.
	^ aRenderer renderActionListPresentation: self! !

GLMFormatedPresentation subclass: #GLMDiffPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDiffPresentation commentStamp: 'TudorGirba 7/14/2011 11:49' prior: 0!
GLMDiffPresentation is meant to show the difference between two input text objects.

The convention is that the transformed entity should provide a collection with two elements.!

!GLMDiffPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderDiffPresentation: self! !

GLMFormatedPresentation subclass: #GLMDropDownListPresentation
	instanceVariableNames: 'selectedIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDropDownListPresentation methodsFor: 'rendering' stamp: ''!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"

	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	^ self displayValue includes: anObject ! !

!GLMDropDownListPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderDropDownListPresentation: self! !

!GLMDropDownListPresentation methodsFor: 'accessing' stamp: ''!
selectedIndex
	^ selectedIndex ifNil:[ selectedIndex := 0 ] ! !

!GLMDropDownListPresentation methodsFor: 'accessing' stamp: ''!
selectedIndex: index
	
	selectedIndex:= index! !

GLMFormatedPresentation subclass: #GLMListingPresentation
	instanceVariableNames: 'searchBlock filterBlock amountToShowBlock allowsMultipleSelection allowsDeselection tagsStyle helpMessage sortBlock textBackgroundColor dropOnItemBlock allowDropOnItemBlock allowItemDragBlock transformDraggedItemBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMListingPresentation commentStamp: 'TudorGirba 2/4/2011 20:41' prior: 0!
This is the abstract class for a presentation that is supposed to show a list of elements. Thus, the displayValue should be a list.

Instance Variables:
	tagsBlock	<Object>
	searchBlock	<MocketryProxy | Object | SMProxy>
	filterBlock	<MocketryProxy | Object | SMProxy>
	amountToShowBlock	<Object>
	allowsMultipleSelection	<Boolean>
	tagsFilterBlock	<MocketryProxy | Object | SMProxy>
	allowsDeselection	<Boolean>
	tagsStyle	<String>
	helpMessage	<String>!

GLMListingPresentation subclass: #GLMListPresentation
	uses: GLMTBlockTags
	instanceVariableNames: 'tagsBlock tagsFilterBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

GLMListPresentation class
	uses: GLMTBlockTags classTrait
	instanceVariableNames: ''!

!GLMListPresentation methodsFor: 'validation' stamp: ''!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"

	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	^ self isMultiple
		ifTrue: [ anObject isCollection and: [
				anObject allSatisfy: [:each | self displayValue includes: each ] ]]
		ifFalse: [ self displayValue includes: anObject ]! !

!GLMListPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderListPresentation: self! !

!GLMListPresentation methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 23:00'!
tagsBlock
	^ tagsBlock! !

!GLMListPresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 23:00'!
tagsBlock: anObject
	tagsBlock := anObject! !

!GLMListPresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 23:00'!
tagsFilter: aBlock
	tagsFilterBlock := aBlock ! !

!GLMListPresentation methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 23:00'!
tagsFilterBlock
	^ tagsFilterBlock! !

!GLMListingPresentation methodsFor: 'accessing values' stamp: ''!
accept: passengerObject droppedOnItem: anItem
	self dropOnItemBlock glamourValue: (GLMMultiValue with: passengerObject with: anItem with: self).
	^ true! !

!GLMListingPresentation methodsFor: 'accessing values' stamp: ''!
allow: passengerObject droppedOnItem: anItem
	^ self allowDropOnItemBlock glamourValue: (GLMMultiValue with: passengerObject with: anItem with: self)! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
allowDeselection
	self allowsDeselection: true! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
allowDropOnItem: aBlock
	allowDropOnItemBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
allowDropOnItemBlock
	^ allowDropOnItemBlock! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
allowItemDrag: aBlock
	allowItemDragBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
allowItemDragBlock
	^ allowItemDragBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
allowsDeselection
	^ allowsDeselection ifNil: [allowsDeselection := false]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
allowsDeselection: anObject
	allowsDeselection := anObject! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
allowsFilter
	^ filterBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
allowsInput
	^ self allowsFilter or: [ self allowsSearch ]! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
allowsItemDrag
	^ self allowItemDragBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
allowsSearch
	^ searchBlock notNil! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'AndreiChis 11/3/2013 12:41'!
amountToShow
	^ (amountToShowBlock ifNil: [ [ self defaultAmountToShow ] ]) glamourValue: self entity! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
beMultiple
	allowsMultipleSelection := true! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
beSingle
	allowsMultipleSelection := false! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
childrenValueOf: anObject
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
childrenValueOf: anObject atLevel: anInteger
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
columns
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 23:01'!
computeTagsFilterFor: aGlamourValue 
	self subclassResponsibility ! !

!GLMListingPresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 23:01'!
computeTagsFor: aGlamourValue 
	self subclassResponsibility ! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'AndreiChis 11/3/2013 12:41'!
defaultAmountToShow
	^ 500! !

!GLMListingPresentation methodsFor: 'accessing values' stamp: ''!
displayValue
	^ sortBlock 
		ifNil: [super displayValue]
		ifNotNil: [super displayValue sorted: sortBlock]! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
dropOnItem: aBlock
	dropOnItemBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
dropOnItemBlock
	^ dropOnItemBlock ! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
filterOn: aBlock 
	filterBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
filterStrategy
	^filterBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
grayRoundedTags

	tagsStyle := #grayRoundedButton! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
helpMessage

	^ helpMessage ifNil: [
		helpMessage := 'Search Input'
		]

	! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
helpMessage: aString

	helpMessage := aString.

	! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
isDragSource 
	^ self dropOnItemBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
isDropTarget
	^ self dropOnItemBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
isMultiple
	^ allowsMultipleSelection ifNil: [ allowsMultipleSelection := false ]! !

!GLMListingPresentation methodsFor: 'testing' stamp: ''!
isSingle 
	^ self isMultiple not! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
searchOn: aBlock
	searchBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
searchStrategy
	^ searchBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
selectionPath
	^ (self pane port: #selectionPath) value! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
selectionPath: anObject
	(self pane port: #selectionPath) value: anObject! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
showOnly: aBlock
	amountToShowBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
sortBlock
	^ sortBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
sortBlock: anObject
	sortBlock := anObject! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
sorted
	sortBlock := [:a :b | a < b]! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
sorted: aBlock
	sortBlock := aBlock  ! !

!GLMListingPresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 22:15'!
tagsFor: anObject fromProvider: aTagProvider to: operation
	| glamourValue |
	
	glamourValue := (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue).
	^ operation == #show 
		ifTrue: [ aTagProvider computeTagsFor: glamourValue ] 
		ifFalse: [ aTagProvider computeTagsFilterFor: glamourValue ]! !

!GLMListingPresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 16:35'!
tagsFor: anObject to: operation
	
	^ self 
		tagsFor: anObject 
		fromProvider: self 
		to: operation! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
tagsStyle

	^tagsStyle ifNil:[ self grayRoundedTags. tagsStyle ]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
textBackgroundColor

	^ textBackgroundColor ifNil: [textBackgroundColor := Color transparent]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
textBackgroundColor:  aBlockOrAColor

	textBackgroundColor := aBlockOrAColor! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
textBackgroundColorFor: anObject
	^ self textBackgroundColor glamourValue: (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue)! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
transformDraggedItem: aBlock
	transformDraggedItemBlock := aBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
transformDraggedItemBlock
	^ transformDraggedItemBlock! !

!GLMListingPresentation methodsFor: 'accessing values' stamp: 'EstebanLorenzano 4/1/2012 12:40'!
transformedDraggedItem: anItem
	^ self transformDraggedItemBlock 
		ifNotNil: [ :transform | transform glamourValue: (GLMMultiValue with: anItem with: self)]
		ifNil: [ anItem ]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: ''!
whiteRectangledTags

	tagsStyle := #whiteRectangledButton! !

!GLMListingPresentation methodsFor: 'scripting' stamp: ''!
withSmalltalkSearch
	self 
		searchOn: [:text :each | 
			Compiler evaluate: ' | entity each | each := self. entity := each.', text for: each logged: false];
		helpMessage: 'Quick selection field. Given your INPUT, it executes: self select: [:each | INPUT ]'! !

GLMListingPresentation subclass: #GLMTablePresentation
	instanceVariableNames: 'columns'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTablePresentation methodsFor: 'accessing' stamp: ''!
addColumn: aColumn
	self columns add: aColumn! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/21/2014 12:37'!
column: aBlockOrString evaluated: aBlock
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock)! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'TudorGirba 5/18/2014 15:56'!
column: aBlockOrString evaluated: aBlock sortedBy: aSortingBlock
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		sortBlock: aSortingBlock)! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/18/2014 00:06'!
column: aBlockOrString evaluated: aBlock tags: anObject 
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		tags: anObject)! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/18/2014 00:06'!
column: aBlockOrString evaluated: aBlock tags: anObject filtered: anotherObject
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		tagsBlock: anObject;
		tagsFilter: anotherObject)! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/21/2014 12:35'!
column: aBlockOrString evaluated: aBlock tags: anObject sortedBy: aSortingBlock
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		tags: anObject;
		sortBlock: aSortingBlock)! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'TudorGirba 6/7/2013 12:52'!
column: aBlockOrString evaluated: aBlock width: aNumber 
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		width: aNumber;
		yourself)	! !

!GLMTablePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/23/2014 13:29'!
column: aBlockOrString evaluated: aBlock width: aNumber tags: anObject
	self addColumn: (GLMTableColumn new 
		title: aBlockOrString; 
		computation: aBlock;
		width: aNumber;
		tags: anObject;
		yourself)	! !

!GLMTablePresentation methodsFor: 'private' stamp: ''!
column: aGlamourColumn valueFor: anObject
	^ aGlamourColumn computation glamourValue: 
		(anObject asGlamorousMultiValue,
		 self entity asGlamorousMultiValue)! !

!GLMTablePresentation methodsFor: 'accessing' stamp: ''!
columns
	^ columns ifNil: [ columns := OrderedCollection new ]! !

!GLMTablePresentation methodsFor: 'accessing' stamp: ''!
columns: aCollection
	columns := aCollection ! !

!GLMTablePresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 16:32'!
computeTagsFilterFor: aGlamourValue
	| tags |
	
	tags := OrderedCollection new.
	self columns collect: [ :aColumn | 
		tags addAll: (aColumn computeTagsFilterFor: aGlamourValue) ].
	^ tags! !

!GLMTablePresentation methodsFor: 'tags' stamp: 'AndreiChis 4/20/2014 16:23'!
computeTagsFor: anObject
	| tags |
	
	tags := OrderedCollection new.
	self columns collect: [ :aColumn | 
		tags addAll: (aColumn computeTagsFor: anObject) ].
	^ tags! !

!GLMTablePresentation methodsFor: 'testing' stamp: 'AndreiChis 4/20/2014 16:02'!
hasTags

	^ self columns anySatisfy: [ :aColumn | aColumn hasTags ]! !

!GLMTablePresentation methodsFor: 'testing' stamp: 'AndreiChis 4/20/2014 16:02'!
hasTagsFilter

	^ self columns anySatisfy: [ :aColumn | aColumn hasTagsFilter ]! !

!GLMTablePresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderTablePresentation: self! !

!GLMTablePresentation methodsFor: 'private' stamp: ''!
titleValueOfColumn: aColumn
	^ aColumn title glamourValue: self entity! !

GLMListingPresentation subclass: #GLMTreePresentation
	uses: GLMTBlockTags
	instanceVariableNames: 'children rootsExpanded allExpanded expandLevel tagsBlock tagsFilterBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

GLMTreePresentation class
	uses: GLMTBlockTags classTrait
	instanceVariableNames: ''!

!GLMTreePresentation methodsFor: 'validation' stamp: ''!
allDisplayedDo: aBlock
	self displayValue do: [ :eachRoot | 
		self withChildrenOf: eachRoot do: aBlock ]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
allExpanded
	self shouldAllExpand: true! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
children 
	 
	^children! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
children: anObject 
	 
	children := anObject! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
childrenValueOf: anObject
	^ self children glamourValue: (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue)! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
childrenValueOf: anObject atLevel: anInteger
	^ self children glamourValue: (
		anObject asGlamorousMultiValue, 
		self entity asGlamorousMultiValue,
		anInteger asGlamorousMultiValue,
		self asGlamorousMultiValue)! !

!GLMTreePresentation methodsFor: 'validation' stamp: ''!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"
	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	self allDisplayedDo: [:each | each = anObject ifTrue: [ ^ true ] ].
	^ false! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'JanKurs 5/27/2013 14:35'!
expandLevel
	^ expandLevel! !

!GLMTreePresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer	
	self registerAnnouncements.
	^ aRenderer renderTreePresentation: self! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
rootsExpanded
	self shouldRootsExpand: true! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
shouldAllExpand
	^ allExpanded ifNil: [false]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
shouldAllExpand: anObject
	allExpanded := anObject! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'JanKurs 5/27/2013 14:33'!
shouldExpandToLevel
	^ expandLevel isNil not! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'JanKurs 5/27/2013 14:34'!
shouldExpandToLevel: level
	^ expandLevel := level! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
shouldRootsExpand
	^ rootsExpanded ifNil: [false]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ''!
shouldRootsExpand: anObject
	rootsExpanded := anObject! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 23:03'!
tagsBlock
	^ tagsBlock! !

!GLMTreePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 23:03'!
tagsBlock: anObject
	tagsBlock := anObject! !

!GLMTreePresentation methodsFor: 'scripting' stamp: 'AndreiChis 4/20/2014 23:04'!
tagsFilter: aBlock
	tagsFilterBlock := aBlock ! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'AndreiChis 4/20/2014 23:03'!
tagsFilterBlock
	^ tagsFilterBlock! !

!GLMTreePresentation methodsFor: 'validation' stamp: ''!
withChildrenOf: anObject do: aBlock
	aBlock value: anObject.
	(self childrenValueOf: anObject) do: [ :each |
		self withChildrenOf: each do: aBlock ]! !

GLMFormatedPresentation subclass: #GLMTextualPresentation
	instanceVariableNames: 'selectedText cursorPosition text doItReceiver doItContext textBlock selectedTextBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

GLMTextualPresentation subclass: #GLMInputPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMInputPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderInputPresentation: self! !

GLMTextualPresentation subclass: #GLMSmalltalkCodePresentation
	instanceVariableNames: 'highlightSmalltalkContext variableBindingsBlock isForScripting'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 12:11'!
beForScripting

	isForScripting := true! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 17:43'!
compileTextIn: aContext from:  aSession 

	self announce: (GLMCompileText new
		presentation: self;
		context: aContext;
		session: aSession)! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 11:18'!
debugSelection

	self announce: GLMDebugSelection! !

!GLMSmalltalkCodePresentation methodsFor: 'rendering' stamp: 'AndreiChis 5/7/2014 11:41'!
defaultSelectionActions

	^ { 
		(GLMGenericAction new) 
				title: 'Print it';
				action: [ :aPresentation |
					aPresentation printSelection ]; 
				shortcut: $p; 
				yourself.
		(GLMGenericAction new) 
				title: 'Do it';
				action: [ :aPresentation |
					aPresentation evaluateSelection ]; 
				shortcut: $d; 
				icon: GLMUIThemeExtraIcons glamorousSpawn;
				yourself.
		(GLMGenericAction new) 
				title: 'Inspect it'; 
				action: [ :aPresentation |
					aPresentation evaluateSelectionAndDo: [ :result | result inspect ] ]; 
				shortcut: $i; 
				icon: GLMUIThemeExtraIcons glamorousInspect;
				yourself.
		(GLMGenericAction new) 
				title: 'Debug it'; 
				action: [ :aPresentation |
					aPresentation debugSelection ]; 
				"shortcut: $D; "
				yourself.
		(GLMGenericAction new) 
				title: 'Profile it'; 
				action: [ :aPresentation |
					aPresentation profileSelection ]; 
				yourself
		 }! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 11:16'!
evaluateSelection

	self evaluateSelectionAndDo: [ :result | result ]! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 11:16'!
evaluateSelectionAndDo: aBlock

	self announce: (GLMEvaluateSelection new action: aBlock)! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: ''!
highlightSmalltalkContext
	^ highlightSmalltalkContext isNil 
		ifTrue: [nil] 
		ifFalse: [highlightSmalltalkContext glamourValue: self entity]! !

!GLMSmalltalkCodePresentation methodsFor: 'rendering' stamp: 'AndreiChis 5/6/2014 14:19'!
installDefaultSelectionActions

	self defaultSelectionActions do: [ :anAction |
		self addSelectionAction: anAction ]

	"self
		selectionAct: [ :aPresentation |
				aPresentation evaluateSelection ]
			on: $d
			entitled: 'Do it';
		selectionAct: [ :aPresentation |
				aPresentation evaluateSelectionAndDo: [ :result | result inspect ] ]
			on: $i
			entitled: 'Inspect it';
		selectionAct: [ :aPresentation |
				aPresentation debugSelection ]
			on: $D
			entitled: 'Debug it';
		selectionAct: [ :aPresentation |
				aPresentation profileSelection ]
			entitled: 'Profile it'"! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: 'AndreiChis 5/6/2014 12:12'!
isForScripting

	^ isForScripting ifNil: [ false ]! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/7/2014 10:57'!
printSelection

	self announce: GLMPrintSelection! !

!GLMSmalltalkCodePresentation methodsFor: 'actions' stamp: 'AndreiChis 5/6/2014 11:26'!
profileSelection

	self announce: GLMProfileSelection! !

!GLMSmalltalkCodePresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderSmalltalkCodePresentation: self! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: ''!
smalltalkClass: aBlock
	"aBlock takes as parameters the entity objects and 
	its evaluation is expected to produce a Smalltalk class"
	highlightSmalltalkContext := aBlock.! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: 'AndreiChis 5/3/2014 18:42'!
updateVariableBindings

	self announce: (GLMVariableBindingsChanged new presentation: self).! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: 'AndreiChis 5/3/2014 18:39'!
variableBindings
	^ (variableBindingsBlock glamourValue: self entity) ifNil: [OrderedCollection new]! !

!GLMSmalltalkCodePresentation methodsFor: 'accessing' stamp: 'AndreiChis 5/3/2014 18:39'!
variableBindings: aBlock
	^ variableBindingsBlock := aBlock! !

GLMTextualPresentation subclass: #GLMTextPresentation
	instanceVariableNames: 'highlightSmalltalk highlightSmalltalkContext'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTextPresentation commentStamp: 'TudorGirba 3/5/2011 21:22' prior: 0!
A presentation displaying text.

Instance Variables:
	selectedTextBlock	<ProtoObject>
	highlightSmalltalk	<Boolean>
	highlightSmalltalkContext	<Object>
	textBlock	<ProtoObject | PseudoContext>!

!GLMTextPresentation methodsFor: 'accessing' stamp: ''!
forSmalltalk
	highlightSmalltalk := true! !

!GLMTextPresentation methodsFor: 'accessing' stamp: ''!
forSmalltalk: aBlock
	"aBlock takes as parameters the entity objects and 
	its evaluation is expected to produce a Smalltalk class"
	highlightSmalltalk := true.
	highlightSmalltalkContext := aBlock.! !

!GLMTextPresentation methodsFor: 'accessing' stamp: ''!
highlightSmalltalk
	^ highlightSmalltalk ifNil: [highlightSmalltalk := false]! !

!GLMTextPresentation methodsFor: 'accessing' stamp: ''!
highlightSmalltalkContext
	^ highlightSmalltalkContext isNil 
		ifTrue: [nil] 
		ifFalse: [highlightSmalltalkContext glamourValue: self entity]! !

!GLMTextPresentation methodsFor: 'rendering' stamp: ''!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderTextPresentation: self! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
cursorPosition 
	 
	^cursorPosition! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
cursorPosition: anObject 
	 
	cursorPosition := anObject! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 8/13/2013 15:43'!
doItContext
	"Return a context use for evaluating code in the presentation. Any variable contained in the executed code will be looked up in this context."
	^ doItContext glamourValue: self entity! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 8/13/2013 15:42'!
doItContext: aOneArgBlock
	"The block will be passed the current entity and is expected to return a context. Any code evaluated from the presentation will be executed as part of the retuned context."
	doItContext := aOneArgBlock! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
doItReceiver
	"Returns the object that should be used when evaluating 'self' within the presentation. 'nil' is the default value"
	^ doItReceiver glamourValue: self entity! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 8/13/2013 15:42'!
doItReceiver: aOneArgBlock
	"The block will be passed the current entity and is expected to return an object .This object will then be returned upon evaluation of 'self' within the presentation."
	doItReceiver := aOneArgBlock! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 4/17/2014 00:24'!
dynamicActionsOnSelection
	"Unlike the other types of presentations, in a text presentation the dynamic actions should be computed even if the selection port is not explicitly populated. A text presentation uses the port #selectedText to transmit the text that was selected by the user, and not the #selection port"
	(selectionDynamicActionsBlock isNil or: [ 
		self selectedText isNil ])
		ifTrue: [ ^ OrderedCollection new ].
	^ selectionDynamicActionsBlock glamourValue: self! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 2/27/2014 17:45'!
selectLine
	"Select the current line if there is no current selection"
	self announce: GLMSelectCurrentLine.! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
selectedText
	^ (self pane port: #selectedText) value isNil 
		ifTrue: [self selectedTextBlock value]
		ifFalse: [(self pane port: #selectedText) value]! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
selectedText: anObject
	(self pane port: #selectedText) value: anObject copy! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
selectedTextBlock
	^ selectedTextBlock ifNil: [ [''] ]! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
selectedTextBlock: anObject
	selectedTextBlock := anObject! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'AndreiChis 6/24/2013 10:12'!
selectionInterval
	^ (self pane port: #selectionInterval) value
! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
selectionInterval: anInterval
	(self pane port: #selectionInterval) value: anInterval! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
text
	^ (self pane port: #text) value isNil 
		ifTrue: [self textBlock value]
		ifFalse: [(self pane port: #text) value]! !

!GLMTextualPresentation methodsFor: 'accessing ports' stamp: ''!
text: aString
	(self pane port: #text) value: aString copy! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
textBlock
	^ textBlock! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: ''!
textBlock: anObject 
	textBlock := anObject! !
